================
Validation cases
================

This page is meant to store extensive validation cases.

Comparison with hydrostatics from Meshmagick
--------------------------------------------

Hydrostatic and inertia properties can be computed independently via Capytaine or Meshmagick.
This script compares them both with analytical expression for a simple geometric object.

.. literalinclude:: src/V_hydrostatics.py
   :language: python

.. literalinclude:: src/V_Malenica_forward_speed.py
   :language: python
